/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/moz2_slave/mozilla-central-linux64-xulrunner/build/dom/interfaces/svg/nsIDOMSVGAnimateElement.idl
 */

#ifndef __gen_nsIDOMSVGAnimateElement_h__
#define __gen_nsIDOMSVGAnimateElement_h__


#ifndef __gen_nsIDOMSVGAnimationElement_h__
#include "nsIDOMSVGAnimationElement.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMSVGAnimateElement */
#define NS_IDOMSVGANIMATEELEMENT_IID_STR "0c4297e8-68d0-471d-a933-64132ccc5b97"

#define NS_IDOMSVGANIMATEELEMENT_IID \
  {0x0c4297e8, 0x68d0, 0x471d, \
    { 0xa9, 0x33, 0x64, 0x13, 0x2c, 0xcc, 0x5b, 0x97 }}

class NS_NO_VTABLE NS_SCRIPTABLE nsIDOMSVGAnimateElement : public nsIDOMSVGAnimationElement {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMSVGANIMATEELEMENT_IID)

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMSVGAnimateElement, NS_IDOMSVGANIMATEELEMENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMSVGANIMATEELEMENT \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMSVGANIMATEELEMENT(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMSVGANIMATEELEMENT(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMSVGAnimateElement : public nsIDOMSVGAnimateElement
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMSVGANIMATEELEMENT

  nsDOMSVGAnimateElement();

private:
  ~nsDOMSVGAnimateElement();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMSVGAnimateElement, nsIDOMSVGAnimateElement)

nsDOMSVGAnimateElement::nsDOMSVGAnimateElement()
{
  /* member initializers and constructor code */
}

nsDOMSVGAnimateElement::~nsDOMSVGAnimateElement()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMSVGAnimateElement_h__ */
